import React from 'react';
import type { Dayjs } from 'dayjs';
import { ButtonProps, ColProps, DividerProps, DropDownProps, MenuItemProps, MenuProps, PageHeaderProps, RowProps, SubMenuProps, TreeDataNode, TreeProps } from 'antd';
declare type MenuItemGroupProps = Record<string, any>;
export declare type G3FieldFCMode = 'read' | 'edit' | 'update';
export declare type G3FieldTextType = React.ReactNode | React.ReactNode[] | Dayjs | Dayjs[];
export declare type G3FieldInputType = 'text' | 'textarea' | 'date' | 'dateRange' | 'timePicker' | 'select' | 'treeSelect' | 'enumSelect' | 'refer' | 'checkbox' | 'radio' | 'radioButton' | 'switch' | 'number' | 'imageUpload' | 'attachUpload' | 'cascade' | 'map';
export declare type G3FieldValueObjectType = {
    type: string;
    status?: 'normal' | 'active' | 'success' | 'exception' | undefined;
};
export declare type G3BaseFieldFC = {
    text?: React.ReactNode;
    fieldProps?: any;
    mode?: G3FieldFCMode;
    label?: React.ReactNode;
    proFieldKey?: React.Key;
};
export declare type RequestOptionsType = {
    label?: React.ReactNode;
    value?: React.ReactText;
    optionType?: 'optGroup' | 'option';
    children?: Omit<RequestOptionsType, 'children' | 'optionType'>[];
    [key: string]: any;
};
export declare type G3FieldRequestData<U = any> = (params: U, props: any) => Promise<RequestOptionsType[]>;
declare type G3FieldSelectBaseProps<T> = {
    text?: string;
    valueEnum?: T;
    request?: G3FieldRequestData;
    params?: Record<string, any>;
    fieldProps?: any;
};
export declare type G3FieldFCRenderProps = {
    mode?: G3FieldFCMode;
    placeholder?: string | string[];
    value?: any;
    onChange?: (...rest: any[]) => void;
} & G3BaseFieldFC;
export declare type G3SchemaValueEnumType = {
    text: React.ReactNode;
    status: string;
    color?: string;
    disabled?: boolean;
};
export declare type G3RenderFieldPropsType = {
    render?: ((text: any, props: Omit<G3FieldFCRenderProps, 'value' | 'onChange'>, dom: JSX.Element) => JSX.Element) | undefined;
    renderFormItem?: ((text: any, props: G3FieldFCRenderProps, dom: JSX.Element) => JSX.Element) | undefined;
};
export declare type G3FieldEmptyText = string | false;
export declare type G3FieldFC<T> = React.ForwardRefRenderFunction<any, G3BaseFieldFC & G3RenderFieldPropsType & T>;
export declare type G3SchemaValueEnumMap = Map<React.ReactText, G3SchemaValueEnumType | React.ReactNode>;
export declare type G3SchemaValueEnumObj = Record<string, G3SchemaValueEnumType | React.ReactNode>;
export interface G3FieldValueEnumEntity {
    label: string;
    value: React.ReactText;
    key?: React.Key;
    disabled?: boolean;
}
export declare type G3FieldValueEnumType = G3SchemaValueEnumMap | G3SchemaValueEnumObj | G3FieldValueEnumEntity[];
export declare type G3FieldSelectProps = G3FieldSelectBaseProps<G3FieldValueEnumType>;
export interface G3FieldTreeEnumEntity extends G3FieldValueEnumEntity {
    children?: G3FieldTreeEnumEntity[];
}
export declare type G3FieldTreeSelectProps = G3FieldSelectBaseProps<G3FieldTreeEnumEntity[]>;
export declare type G3RequestData<T, U = Record<string, any>> = (params: U, props?: any) => Promise<T>;
export interface G3MenuItemProps extends MenuItemProps {
    key?: string | number;
}
export interface G3SubMenuProps extends SubMenuProps {
    key?: string | number;
}
export interface G3MenuItemGroupProps extends MenuItemGroupProps {
    key?: string | number;
}
export interface G3MenuDividerProps extends DividerProps {
    key?: string | number;
}
export declare enum MENU_TYPES {
    ITEM = 0,
    SUB_ITEM = 1,
    ITEM_GROUP = 2,
    ITEM_DIVIDER = 3
}
export interface G3MenuItemType extends G3MenuItemProps {
    menuType: MENU_TYPES;
    subItems?: G3MenuTypes[];
}
export interface G3SubMenuType extends G3SubMenuProps {
    menuType: MENU_TYPES;
    subItems?: G3MenuTypes[];
}
export interface G3MenuItemGroupType extends G3MenuItemGroupProps {
    menuType: MENU_TYPES;
    subItems?: G3MenuTypes[];
}
export interface G3MenuDividerType extends G3MenuDividerProps {
    menuType: MENU_TYPES;
    subItems?: G3MenuTypes[];
}
export declare type G3MenuTypes = G3MenuItemType | G3SubMenuType | G3MenuItemGroupType | G3MenuDividerType;
export interface G3MenuProps extends MenuProps {
    items?: G3MenuTypes[];
}
export interface G3MenuRef {
    setVisible: (visible: boolean) => void;
}
export interface G3MenuItemRef {
    setVisible: (visible: boolean) => void;
}
export interface G3SubMenuRef {
    setVisible: (visible: boolean) => void;
}
export interface G3MenuDividerRef {
    setVisible: (visible: boolean) => void;
}
export interface G3MenuItemGroupRef {
    setVisible: (visible: boolean) => void;
}
export interface G3PageHeaderButtonProps extends G3ButtonProps {
    key: number | string;
}
export interface G3PageHeaderProps extends PageHeaderProps {
    buttonShowNum?: number;
    buttonList?: G3PageHeaderButtonProps[];
    children?: any;
}
export interface G3PageHeaderRef {
    setVisible: (visible: boolean) => void;
}
export interface G3ButtonProps extends ButtonProps {
    label?: string;
}
export interface G3ButtonRef {
    setVisible: (visible: boolean) => void;
}
export interface G3ButtonGroupRef {
    setVisible: (visible: boolean) => void;
}
export interface G3ButtonGroupProps {
    size?: 'small' | 'middle' | 'large' | undefined;
    style?: React.CSSProperties;
    className?: string;
    prefixCls?: string;
    children?: any;
}
export interface G3DropDownMenuItem {
    key: string | number;
    title: string;
    subMenus?: G3DropDownMenuItem[];
}
declare type OverlayFunc = () => React.ReactElement;
export interface G3DropDownProps extends Omit<DropDownProps, 'overlay'> {
    overlay?: React.ReactElement | OverlayFunc;
    menus?: G3DropDownMenuItem[];
    label?: string;
    children?: any;
}
export interface G3DropDownRef {
    setVisible: (visible: boolean) => void;
}
export interface G3DropDownButtonRef {
    setVisible: (visible: boolean) => void;
}
export declare type G3RowProps = RowProps;
export interface G3RowRef {
    setVisible: (visible: boolean) => void;
}
export declare type G3ColProps = ColProps;
export interface G3ColRef {
    setVisible: (visible: boolean) => void;
}
export declare type G3TreeDataNode = TreeDataNode;
export interface G3TreeProps extends TreeProps {
    search?: {
        placeholder?: string;
    };
}
export interface G3TreeRef {
    setVisible: (visible: boolean) => void;
}
export {};
